from kio.schema.share_acknowledge.v0.request import (
    ShareAcknowledgeRequest as ShareAcknowledgeRequestV0,
)
from kio.schema.share_acknowledge.v0.request import (
    RequestHeader as ShareAcknowledgeRequestHeaderV0,
)
from kio.schema.share_acknowledge.v0.response import (
    ShareAcknowledgeResponse as ShareAcknowledgeResponseV0,
)
from kio.schema.share_acknowledge.v0.response import (
    ResponseHeader as ShareAcknowledgeResponseHeaderV0,
)

ShareAcknowledgeRequestHeader = ShareAcknowledgeRequestHeaderV0

ShareAcknowledgeResponseHeader = ShareAcknowledgeResponseHeaderV0

ShareAcknowledgeRequest = ShareAcknowledgeRequestV0

ShareAcknowledgeResponse = ShareAcknowledgeResponseV0
