from kio.schema.allocate_producer_ids.v0.request import (
    AllocateProducerIdsRequest as AllocateProducerIdsRequestV0,
)
from kio.schema.allocate_producer_ids.v0.request import (
    RequestHeader as AllocateProducerIdsRequestHeaderV0,
)
from kio.schema.allocate_producer_ids.v0.response import (
    AllocateProducerIdsResponse as AllocateProducerIdsResponseV0,
)
from kio.schema.allocate_producer_ids.v0.response import (
    ResponseHeader as AllocateProducerIdsResponseHeaderV0,
)

AllocateProducerIdsRequestHeader = AllocateProducerIdsRequestHeaderV0
AllocateProducerIdsResponseHeader = AllocateProducerIdsResponseHeaderV0
AllocateProducerIdsRequest = AllocateProducerIdsRequestV0
AllocateProducerIdsResponse = AllocateProducerIdsResponseV0
