from kio.schema.initialize_share_group_state.v0.request import (
    InitializeShareGroupStateRequest as InitializeShareGroupStateRequestV0,
)
from kio.schema.initialize_share_group_state.v0.request import (
    RequestHeader as InitializeShareGroupStateRequestHeaderV0,
)
from kio.schema.initialize_share_group_state.v0.response import (
    InitializeShareGroupStateResponse as InitializeShareGroupStateResponseV0,
)
from kio.schema.initialize_share_group_state.v0.response import (
    ResponseHeader as InitializeShareGroupStateResponseHeaderV0,
)

InitializeShareGroupStateRequestHeader = InitializeShareGroupStateRequestHeaderV0

InitializeShareGroupStateResponseHeader = InitializeShareGroupStateResponseHeaderV0

InitializeShareGroupStateRequest = InitializeShareGroupStateRequestV0

InitializeShareGroupStateResponse = InitializeShareGroupStateResponseV0
