from kio.schema.update_raft_voter.v0.request import (
    UpdateRaftVoterRequest as UpdateRaftVoterRequestV0,
)
from kio.schema.update_raft_voter.v0.request import (
    RequestHeader as UpdateRaftVoterRequestHeaderV0,
)
from kio.schema.update_raft_voter.v0.response import (
    UpdateRaftVoterResponse as UpdateRaftVoterResponseV0,
)
from kio.schema.update_raft_voter.v0.response import (
    ResponseHeader as UpdateRaftVoterResponseHeaderV0,
)

UpdateRaftVoterRequestHeader = UpdateRaftVoterRequestHeaderV0
UpdateRaftVoterResponseHeader = UpdateRaftVoterResponseHeaderV0
UpdateRaftVoterRequest = UpdateRaftVoterRequestV0
UpdateRaftVoterResponse = UpdateRaftVoterResponseV0
