from kio.schema.alter_partition_reassignments.v0.request import (
    AlterPartitionReassignmentsRequest as AlterPartitionReassignmentsRequestV0,
)
from kio.schema.alter_partition_reassignments.v0.request import (
    RequestHeader as AlterPartitionReassignmentsRequestHeaderV0,
)
from kio.schema.alter_partition_reassignments.v0.response import (
    AlterPartitionReassignmentsResponse as AlterPartitionReassignmentsResponseV0,
)
from kio.schema.alter_partition_reassignments.v0.response import (
    ResponseHeader as AlterPartitionReassignmentsResponseHeaderV0,
)

AlterPartitionReassignmentsRequestHeader = AlterPartitionReassignmentsRequestHeaderV0
AlterPartitionReassignmentsResponseHeader = AlterPartitionReassignmentsResponseHeaderV0
AlterPartitionReassignmentsRequest = AlterPartitionReassignmentsRequestV0
AlterPartitionReassignmentsResponse = AlterPartitionReassignmentsResponseV0
