from kio.schema.describe_user_scram_credentials.v0.request import (
    DescribeUserScramCredentialsRequest as DescribeUserScramCredentialsRequestV0,
)
from kio.schema.describe_user_scram_credentials.v0.request import (
    RequestHeader as DescribeUserScramCredentialsRequestHeaderV0,
)
from kio.schema.describe_user_scram_credentials.v0.response import (
    DescribeUserScramCredentialsResponse as DescribeUserScramCredentialsResponseV0,
)
from kio.schema.describe_user_scram_credentials.v0.response import (
    ResponseHeader as DescribeUserScramCredentialsResponseHeaderV0,
)

DescribeUserScramCredentialsRequestHeader = DescribeUserScramCredentialsRequestHeaderV0
DescribeUserScramCredentialsResponseHeader = DescribeUserScramCredentialsResponseHeaderV0
DescribeUserScramCredentialsRequest = DescribeUserScramCredentialsRequestV0
DescribeUserScramCredentialsResponse = DescribeUserScramCredentialsResponseV0
