from kio.schema.consumer_group_heartbeat.v0.request import (
    ConsumerGroupHeartbeatRequest as ConsumerGroupHeartbeatRequestV0,
)
from kio.schema.consumer_group_heartbeat.v0.request import (
    RequestHeader as ConsumerGroupHeartbeatRequestHeaderV0,
)
from kio.schema.consumer_group_heartbeat.v0.response import (
    ConsumerGroupHeartbeatResponse as ConsumerGroupHeartbeatResponseV0,
)
from kio.schema.consumer_group_heartbeat.v0.response import (
    ResponseHeader as ConsumerGroupHeartbeatResponseHeaderV0,
)

ConsumerGroupHeartbeatRequestHeader = ConsumerGroupHeartbeatRequestHeaderV0
ConsumerGroupHeartbeatResponseHeader = ConsumerGroupHeartbeatResponseHeaderV0
ConsumerGroupHeartbeatRequest = ConsumerGroupHeartbeatRequestV0
ConsumerGroupHeartbeatResponse = ConsumerGroupHeartbeatResponseV0
