from kio.schema.envelope.v0.request import (
    EnvelopeRequest as EnvelopeRequestV0,
)
from kio.schema.envelope.v0.request import (
    RequestHeader as EnvelopeRequestHeaderV0,
)
from kio.schema.envelope.v0.response import (
    EnvelopeResponse as EnvelopeResponseV0,
)
from kio.schema.envelope.v0.response import (
    ResponseHeader as EnvelopeResponseHeaderV0,
)

EnvelopeRequestHeader = EnvelopeRequestHeaderV0
EnvelopeResponseHeader = EnvelopeResponseHeaderV0
EnvelopeRequest = EnvelopeRequestV0
EnvelopeResponse = EnvelopeResponseV0
