from kio.schema.alter_user_scram_credentials.v0.request import (
    AlterUserScramCredentialsRequest as AlterUserScramCredentialsRequestV0,
)
from kio.schema.alter_user_scram_credentials.v0.request import (
    RequestHeader as AlterUserScramCredentialsRequestHeaderV0,
)
from kio.schema.alter_user_scram_credentials.v0.response import (
    AlterUserScramCredentialsResponse as AlterUserScramCredentialsResponseV0,
)
from kio.schema.alter_user_scram_credentials.v0.response import (
    ResponseHeader as AlterUserScramCredentialsResponseHeaderV0,
)

AlterUserScramCredentialsRequestHeader = AlterUserScramCredentialsRequestHeaderV0
AlterUserScramCredentialsResponseHeader = AlterUserScramCredentialsResponseHeaderV0
AlterUserScramCredentialsRequest = AlterUserScramCredentialsRequestV0
AlterUserScramCredentialsResponse = AlterUserScramCredentialsResponseV0
