from kio.schema.offset_delete.v0.request import (
    OffsetDeleteRequest as OffsetDeleteRequestV0,
)
from kio.schema.offset_delete.v0.request import (
    RequestHeader as OffsetDeleteRequestHeaderV0,
)
from kio.schema.offset_delete.v0.response import (
    OffsetDeleteResponse as OffsetDeleteResponseV0,
)
from kio.schema.offset_delete.v0.response import (
    ResponseHeader as OffsetDeleteResponseHeaderV0,
)

OffsetDeleteRequestHeader = OffsetDeleteRequestHeaderV0

OffsetDeleteResponseHeader = OffsetDeleteResponseHeaderV0

OffsetDeleteRequest = OffsetDeleteRequestV0

OffsetDeleteResponse = OffsetDeleteResponseV0
