from kio.schema.describe_transactions.v0.request import (
    DescribeTransactionsRequest as DescribeTransactionsRequestV0,
)
from kio.schema.describe_transactions.v0.request import (
    RequestHeader as DescribeTransactionsRequestHeaderV0,
)
from kio.schema.describe_transactions.v0.response import (
    DescribeTransactionsResponse as DescribeTransactionsResponseV0,
)
from kio.schema.describe_transactions.v0.response import (
    ResponseHeader as DescribeTransactionsResponseHeaderV0,
)

DescribeTransactionsRequestHeader = DescribeTransactionsRequestHeaderV0
DescribeTransactionsResponseHeader = DescribeTransactionsResponseHeaderV0
DescribeTransactionsRequest = DescribeTransactionsRequestV0
DescribeTransactionsResponse = DescribeTransactionsResponseV0
