from kio.schema.add_raft_voter.v0.request import (
    AddRaftVoterRequest as AddRaftVoterRequestV0,
)
from kio.schema.add_raft_voter.v0.request import (
    RequestHeader as AddRaftVoterRequestHeaderV0,
)
from kio.schema.add_raft_voter.v0.response import (
    AddRaftVoterResponse as AddRaftVoterResponseV0,
)
from kio.schema.add_raft_voter.v0.response import (
    ResponseHeader as AddRaftVoterResponseHeaderV0,
)

AddRaftVoterRequestHeader = AddRaftVoterRequestHeaderV0
AddRaftVoterResponseHeader = AddRaftVoterResponseHeaderV0
AddRaftVoterRequest = AddRaftVoterRequestV0
AddRaftVoterResponse = AddRaftVoterResponseV0
