from kio.schema.write_share_group_state.v0.request import (
    WriteShareGroupStateRequest as WriteShareGroupStateRequestV0,
)
from kio.schema.write_share_group_state.v0.request import (
    RequestHeader as WriteShareGroupStateRequestHeaderV0,
)
from kio.schema.write_share_group_state.v0.response import (
    WriteShareGroupStateResponse as WriteShareGroupStateResponseV0,
)
from kio.schema.write_share_group_state.v0.response import (
    ResponseHeader as WriteShareGroupStateResponseHeaderV0,
)

WriteShareGroupStateRequestHeader = WriteShareGroupStateRequestHeaderV0
WriteShareGroupStateResponseHeader = WriteShareGroupStateResponseHeaderV0
WriteShareGroupStateRequest = WriteShareGroupStateRequestV0
WriteShareGroupStateResponse = WriteShareGroupStateResponseV0
