from kio.schema.remove_raft_voter.v0.request import (
    RemoveRaftVoterRequest as RemoveRaftVoterRequestV0,
)
from kio.schema.remove_raft_voter.v0.request import (
    RequestHeader as RemoveRaftVoterRequestHeaderV0,
)
from kio.schema.remove_raft_voter.v0.response import (
    RemoveRaftVoterResponse as RemoveRaftVoterResponseV0,
)
from kio.schema.remove_raft_voter.v0.response import (
    ResponseHeader as RemoveRaftVoterResponseHeaderV0,
)

RemoveRaftVoterRequestHeader = RemoveRaftVoterRequestHeaderV0

RemoveRaftVoterResponseHeader = RemoveRaftVoterResponseHeaderV0

RemoveRaftVoterRequest = RemoveRaftVoterRequestV0

RemoveRaftVoterResponse = RemoveRaftVoterResponseV0
