from kio.schema.share_group_describe.v0.request import (
    ShareGroupDescribeRequest as ShareGroupDescribeRequestV0,
)
from kio.schema.share_group_describe.v0.request import (
    RequestHeader as ShareGroupDescribeRequestHeaderV0,
)
from kio.schema.share_group_describe.v0.response import (
    ShareGroupDescribeResponse as ShareGroupDescribeResponseV0,
)
from kio.schema.share_group_describe.v0.response import (
    ResponseHeader as ShareGroupDescribeResponseHeaderV0,
)

ShareGroupDescribeRequestHeader = ShareGroupDescribeRequestHeaderV0

ShareGroupDescribeResponseHeader = ShareGroupDescribeResponseHeaderV0

ShareGroupDescribeRequest = ShareGroupDescribeRequestV0

ShareGroupDescribeResponse = ShareGroupDescribeResponseV0
