from kio.schema.list_partition_reassignments.v0.request import (
    ListPartitionReassignmentsRequest as ListPartitionReassignmentsRequestV0,
)
from kio.schema.list_partition_reassignments.v0.request import (
    RequestHeader as ListPartitionReassignmentsRequestHeaderV0,
)
from kio.schema.list_partition_reassignments.v0.response import (
    ListPartitionReassignmentsResponse as ListPartitionReassignmentsResponseV0,
)
from kio.schema.list_partition_reassignments.v0.response import (
    ResponseHeader as ListPartitionReassignmentsResponseHeaderV0,
)


ListPartitionReassignmentsRequestHeader = ListPartitionReassignmentsRequestHeaderV0

ListPartitionReassignmentsResponseHeader = ListPartitionReassignmentsResponseHeaderV0

ListPartitionReassignmentsRequest = ListPartitionReassignmentsRequestV0

ListPartitionReassignmentsResponse = ListPartitionReassignmentsResponseV0
