from kio.schema.read_share_group_state.v0.request import (
    ReadShareGroupStateRequest as ReadShareGroupStateRequestV0,
)
from kio.schema.read_share_group_state.v0.request import (
    RequestHeader as ReadShareGroupStateRequestHeaderV0,
)
from kio.schema.read_share_group_state.v0.response import (
    ReadShareGroupStateResponse as ReadShareGroupStateResponseV0,
)
from kio.schema.read_share_group_state.v0.response import (
    ResponseHeader as ReadShareGroupStateResponseHeaderV0,
)

ReadShareGroupStateRequestHeader = ReadShareGroupStateRequestHeaderV0

ReadShareGroupStateResponseHeader = ReadShareGroupStateResponseHeaderV0

ReadShareGroupStateRequest = ReadShareGroupStateRequestV0

ReadShareGroupStateResponse = ReadShareGroupStateResponseV0
