from kio.schema.get_telemetry_subscriptions.v0.request import (
    GetTelemetrySubscriptionsRequest as GetTelemetrySubscriptionsRequestV0,
)
from kio.schema.get_telemetry_subscriptions.v0.request import (
    RequestHeader as GetTelemetrySubscriptionsRequestHeaderV0,
)
from kio.schema.get_telemetry_subscriptions.v0.response import (
    GetTelemetrySubscriptionsResponse as GetTelemetrySubscriptionsResponseV0,
)
from kio.schema.get_telemetry_subscriptions.v0.response import (
    ResponseHeader as GetTelemetrySubscriptionsResponseHeaderV0,
)

GetTelemetrySubscriptionsRequestHeader = GetTelemetrySubscriptionsRequestHeaderV0

GetTelemetrySubscriptionsResponseHeader = GetTelemetrySubscriptionsResponseHeaderV0

GetTelemetrySubscriptionsRequest = GetTelemetrySubscriptionsRequestV0

GetTelemetrySubscriptionsResponse = GetTelemetrySubscriptionsResponseV0
