from kio.schema.unregister_broker.v0.request import (
    UnregisterBrokerRequest as UnregisterBrokerRequestV0,
)
from kio.schema.unregister_broker.v0.request import (
    RequestHeader as UnregisterBrokerRequestHeaderV0,
)
from kio.schema.unregister_broker.v0.response import (
    UnregisterBrokerResponse as UnregisterBrokerResponseV0,
)
from kio.schema.unregister_broker.v0.response import (
    ResponseHeader as UnregisterBrokerResponseHeaderV0,
)

UnregisterBrokerRequestHeader = UnregisterBrokerRequestHeaderV0
UnregisterBrokerResponseHeader = UnregisterBrokerResponseHeaderV0
UnregisterBrokerRequest = UnregisterBrokerRequestV0
UnregisterBrokerResponse = UnregisterBrokerResponseV0
