from kio.schema.describe_producers.v0.request import (
    DescribeProducersRequest as DescribeProducersRequestV0,
)
from kio.schema.describe_producers.v0.request import (
    RequestHeader as DescribeProducersRequestHeaderV0,
)
from kio.schema.describe_producers.v0.response import (
    DescribeProducersResponse as DescribeProducersResponseV0,
)
from kio.schema.describe_producers.v0.response import (
    ResponseHeader as DescribeProducersResponseHeaderV0,
)

DescribeProducersRequestHeader = DescribeProducersRequestHeaderV0
DescribeProducersResponseHeader = DescribeProducersResponseHeaderV0
DescribeProducersRequest = DescribeProducersRequestV0
DescribeProducersResponse = DescribeProducersResponseV0
