from kio.schema.assign_replicas_to_dirs.v0.request import (
    AssignReplicasToDirsRequest as AssignReplicasToDirsRequestV0,
)
from kio.schema.assign_replicas_to_dirs.v0.request import (
    RequestHeader as AssignReplicasToDirsRequestHeaderV0,
)
from kio.schema.assign_replicas_to_dirs.v0.response import (
    AssignReplicasToDirsResponse as AssignReplicasToDirsResponseV0,
)
from kio.schema.assign_replicas_to_dirs.v0.response import (
    ResponseHeader as AssignReplicasToDirsResponseHeaderV0,
)

AssignReplicasToDirsRequestHeader = AssignReplicasToDirsRequestHeaderV0
AssignReplicasToDirsResponseHeader = AssignReplicasToDirsResponseHeaderV0
AssignReplicasToDirsRequest = AssignReplicasToDirsRequestV0
AssignReplicasToDirsResponse = AssignReplicasToDirsResponseV0
