from kio.schema.consumer_group_describe.v0.request import (
    ConsumerGroupDescribeRequest as ConsumerGroupDescribeRequestV0,
)
from kio.schema.consumer_group_describe.v0.request import (
    RequestHeader as ConsumerGroupDescribeRequestHeaderV0,
)
from kio.schema.consumer_group_describe.v0.response import (
    ConsumerGroupDescribeResponse as ConsumerGroupDescribeResponseV0,
)
from kio.schema.consumer_group_describe.v0.response import (
    ResponseHeader as ConsumerGroupDescribeResponseHeaderV0,
)

ConsumerGroupDescribeRequestHeader = ConsumerGroupDescribeRequestHeaderV0
ConsumerGroupDescribeResponseHeader = ConsumerGroupDescribeResponseHeaderV0
ConsumerGroupDescribeRequest = ConsumerGroupDescribeRequestV0
ConsumerGroupDescribeResponse = ConsumerGroupDescribeResponseV0
