from kio.schema.controller_registration.v0.request import (
    ControllerRegistrationRequest as ControllerRegistrationRequestV0,
)
from kio.schema.controller_registration.v0.request import (
    RequestHeader as ControllerRegistrationRequestHeaderV0,
)
from kio.schema.controller_registration.v0.response import (
    ControllerRegistrationResponse as ControllerRegistrationResponseV0,
)
from kio.schema.controller_registration.v0.response import (
    ResponseHeader as ControllerRegistrationResponseHeaderV0,
)

ControllerRegistrationRequestHeader = ControllerRegistrationRequestHeaderV0
ControllerRegistrationResponseHeader = ControllerRegistrationResponseHeaderV0
ControllerRegistrationRequest = ControllerRegistrationRequestV0
ControllerRegistrationResponse = ControllerRegistrationResponseV0
