"""add log_start_offset to partition

Revision ID: c354df1a9089
Revises: bf37d72775bc
Create Date: 2025-06-25 17:20:54.111573

"""

from typing import Sequence, Union

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = "c354df1a9089"
down_revision: Union[str, None] = "bf37d72775bc"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "partitions", sa.Column("log_start_offset", sa.BigInteger(), nullable=False)
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("partitions", "log_start_offset")
    # ### end Alembic commands ###
