from kio.schema.list_client_metrics_resources.v0.request import (
    ListClientMetricsResourcesRequest as ListClientMetricsResourcesRequestV0,
)
from kio.schema.list_client_metrics_resources.v0.request import (
    RequestHeader as ListClientMetricsResourcesRequestHeaderV0,
)
from kio.schema.list_client_metrics_resources.v0.response import (
    ListClientMetricsResourcesResponse as ListClientMetricsResourcesResponseV0,
)
from kio.schema.list_client_metrics_resources.v0.response import (
    ResponseHeader as ListClientMetricsResourcesResponseHeaderV0,
)

ListClientMetricsResourcesRequestHeader = ListClientMetricsResourcesRequestHeaderV0

ListClientMetricsResourcesResponseHeader = ListClientMetricsResourcesResponseHeaderV0

ListClientMetricsResourcesRequest = ListClientMetricsResourcesRequestV0

ListClientMetricsResourcesResponse = ListClientMetricsResourcesResponseV0
