from kio.schema.read_share_group_state_summary.v0.request import (
    ReadShareGroupStateSummaryRequest as ReadShareGroupStateSummaryRequestV0,
)
from kio.schema.read_share_group_state_summary.v0.request import (
    RequestHeader as ReadShareGroupStateSummaryRequestHeaderV0,
)
from kio.schema.read_share_group_state_summary.v0.response import (
    ReadShareGroupStateSummaryResponse as ReadShareGroupStateSummaryResponseV0,
)
from kio.schema.read_share_group_state_summary.v0.response import (
    ResponseHeader as ReadShareGroupStateSummaryResponseHeaderV0,
)

ReadShareGroupStateSummaryRequestHeader = ReadShareGroupStateSummaryRequestHeaderV0

ReadShareGroupStateSummaryResponseHeader = ReadShareGroupStateSummaryResponseHeaderV0

ReadShareGroupStateSummaryRequest = ReadShareGroupStateSummaryRequestV0

ReadShareGroupStateSummaryResponse = ReadShareGroupStateSummaryResponseV0
