from kio.schema.delete_share_group_state.v0.request import (
    DeleteShareGroupStateRequest as DeleteShareGroupStateRequestV0,
)
from kio.schema.delete_share_group_state.v0.request import (
    RequestHeader as DeleteShareGroupStateRequestHeaderV0,
)
from kio.schema.delete_share_group_state.v0.response import (
    DeleteShareGroupStateResponse as DeleteShareGroupStateResponseV0,
)
from kio.schema.delete_share_group_state.v0.response import (
    ResponseHeader as DeleteShareGroupStateResponseHeaderV0,
)

DeleteShareGroupStateRequestHeader = DeleteShareGroupStateRequestHeaderV0
DeleteShareGroupStateResponseHeader = DeleteShareGroupStateResponseHeaderV0
DeleteShareGroupStateRequest = DeleteShareGroupStateRequestV0
DeleteShareGroupStateResponse = DeleteShareGroupStateResponseV0
