from kio.schema.share_group_heartbeat.v0.request import (
    ShareGroupHeartbeatRequest as ShareGroupHeartbeatRequestV0,
)
from kio.schema.share_group_heartbeat.v0.request import (
    RequestHeader as ShareGroupHeartbeatRequestHeaderV0,
)
from kio.schema.share_group_heartbeat.v0.response import (
    ShareGroupHeartbeatResponse as ShareGroupHeartbeatResponseV0,
)
from kio.schema.share_group_heartbeat.v0.response import (
    ResponseHeader as ShareGroupHeartbeatResponseHeaderV0,
)


ShareGroupHeartbeatRequestHeader = ShareGroupHeartbeatRequestHeaderV0

ShareGroupHeartbeatResponseHeader = ShareGroupHeartbeatResponseHeaderV0

ShareGroupHeartbeatRequest = ShareGroupHeartbeatRequestV0

ShareGroupHeartbeatResponse = ShareGroupHeartbeatResponseV0
