from kio.schema.describe_topic_partitions.v0.request import (
    DescribeTopicPartitionsRequest as DescribeTopicPartitionsRequestV0,
)
from kio.schema.describe_topic_partitions.v0.request import (
    RequestHeader as DescribeTopicPartitionsRequestHeaderV0,
)
from kio.schema.describe_topic_partitions.v0.response import (
    DescribeTopicPartitionsResponse as DescribeTopicPartitionsResponseV0,
)
from kio.schema.describe_topic_partitions.v0.response import (
    ResponseHeader as DescribeTopicPartitionsResponseHeaderV0,
)

DescribeTopicPartitionsRequestHeader = DescribeTopicPartitionsRequestHeaderV0
DescribeTopicPartitionsResponseHeader = DescribeTopicPartitionsResponseHeaderV0
DescribeTopicPartitionsRequest = DescribeTopicPartitionsRequestV0
DescribeTopicPartitionsResponse = DescribeTopicPartitionsResponseV0
