from kio.schema.push_telemetry.v0.request import (
    PushTelemetryRequest as PushTelemetryRequestV0,
)
from kio.schema.push_telemetry.v0.request import (
    RequestHeader as PushTelemetryRequestHeaderV0,
)
from kio.schema.push_telemetry.v0.response import (
    PushTelemetryResponse as PushTelemetryResponseV0,
)
from kio.schema.push_telemetry.v0.response import (
    ResponseHeader as PushTelemetryResponseHeaderV0,
)

PushTelemetryRequestHeader = PushTelemetryRequestHeaderV0

PushTelemetryResponseHeader = PushTelemetryResponseHeaderV0

PushTelemetryRequest = PushTelemetryRequestV0

PushTelemetryResponse = PushTelemetryResponseV0
