from kio.schema.share_fetch.v0.request import (
    ShareFetchRequest as ShareFetchRequestV0,
)
from kio.schema.share_fetch.v0.request import (
    RequestHeader as ShareFetchRequestHeaderV0,
)
from kio.schema.share_fetch.v0.response import (
    ShareFetchResponse as ShareFetchResponseV0,
)
from kio.schema.share_fetch.v0.response import (
    ResponseHeader as ShareFetchResponseHeaderV0,
)

ShareFetchRequestHeader = ShareFetchRequestHeaderV0

ShareFetchResponseHeader = ShareFetchResponseHeaderV0

ShareFetchRequest = ShareFetchRequestV0

ShareFetchResponse = ShareFetchResponseV0
